package main

import (
	"flag"
	"fmt"
	"fusenapi/server/websocket/internal/logic"
	"fusenapi/utils/auth"
	"fusenapi/utils/fsconfig"
	"github.com/zeromicro/go-zero/core/logx"
	"net/http"

	"fusenapi/server/websocket/internal/config"
	"fusenapi/server/websocket/internal/handler"
	"fusenapi/server/websocket/internal/svc"

	"github.com/zeromicro/go-zero/rest"
)

var configFile = flag.String("f", "etc/websocket.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	fsconfig.StartNacosConfig(*configFile, &c, nil)
	server := rest.MustNewServer(c.RestConf, rest.WithCustomCors(auth.FsCors, func(w http.ResponseWriter) {
	}))
	defer server.Stop()

	ctx := svc.NewServiceContext(c)
	handler.RegisterHandlers(server, ctx)
	//消费公共通知队列的数据
	go logic.ConsumeCommonCacheData()
	//消费用户索引创建/删除/发送消息中的任务数据
	go logic.ConsumeUserConnPoolCtlChanData()
	//消费连接统计信息
	go logic.ConsumeWebsocketStatData()
	//拨号udp消费控制unity取消僵尸任务的消息
	if err := logic.DialUdp(c); err != nil {
		logx.Error("dail udp err:", err)
		return
	}
	fmt.Printf("Starting server at %s:%d...\n", c.Host, c.Port)
	server.Start()
}
